@@ -22,32 +22,40 @@ int main(int argc, char** argv)
 	int N = 100;
 	int nev = 2;
 
-	double* matrix = new double[N*N];
-
-	double* eigenvalues = new double[nev];
-	double* eigenvectors = new double[nev*N];
+	double* double_matrix = new double[N*N];
+	double* rhs_double_diag = new double[N];
+	double* double_eigenvalues = new double[nev];
+	double* double_eigenvectors = new double[nev*N];
 
 	for (int i=0; i<N; i++)
 	{
+		rhs_double_diag[i] = 1.0;
 		for (int j=0; j<N; j++)
-			matrix[i*N+j] = i*i+j*j;
+		{
+			double_matrix[i*N+j] = i*i+j*j;
+		}
 	}
 
 	int status = 0;
-	arpack_dsaeupd_wrap(matrix, NULL, N, 2, "LM", 1, false, 0.0, 0.0,
-	                    eigenvalues, eigenvectors, status);
+	arpack_dsxupd(double_matrix, NULL, false, N, 2, "LM", false, 1, false, 0.0, 0.0,
+	              double_eigenvalues, double_eigenvectors, status);
 	if (status!=0)
 		return -1;
 
-	arpack_dsaeupd_wrap(matrix, NULL, N, 2, "BE", 3, false, 1.0, 0.0,
-	                    eigenvalues, eigenvectors, status);
+	arpack_dsxupd(double_matrix, NULL, false, N, 2, "BE", false, 3, false, 1.0, 0.0,
+	              double_eigenvalues, double_eigenvectors, status);
 	if (status!=0)
 		return -1;
 
+	arpack_dsxupd(double_matrix, rhs_double_diag, true, N, 2, "SM", false, 3, false, 0.0, 0.0,
+	              double_eigenvalues, double_eigenvectors, status);
+	if (status!=0)
+		return -1;
 
-	delete[] eigenvalues;
-	delete[] eigenvectors;
-	delete[] matrix;
+	delete[] double_eigenvalues;
+	delete[] double_eigenvectors;
+	delete[] double_matrix;
+	delete[] rhs_double_diag;
 #endif // HAVE_ARPACK
 
 	exit_shogun();
