@@ -13,7 +13,6 @@ testlab=[-ones(1,num), ones(1,num)];
 
 feats_train=RealFeatures(traindata_real);
 feats_test=RealFeatures(testdata_real);
-feats_test.copy_feature_matrix(testdata_real);
 kernel=GaussianKernel(feats_train, feats_train, width);
 
 labels=Labels(trainlab);
@@ -21,5 +20,5 @@ svm=LibSVM(C, kernel, labels);
 svm.parallel.set_num_threads(8);
 svm.train();
 kernel.init(feats_train, feats_test);
-out=svm.classify().get_labels();
+out=svm.apply().get_labels();
 testerr=mean(sign(out)~=testlab)
