@@ -24,4 +24,4 @@ svm.parallel.set_num_threads(num_threads);
 svm.train();
 
 kernel.init(feats_train, feats_test);
-svm.classify().get_labels();
+svm.apply().get_labels();
