@@ -17,15 +17,15 @@ feats_train=StringUlongFeatures(charfeat.get_alphabet());
 feats_train.obtain_from_char(charfeat, order-1, order, gap, reverse);
 preproc=SortUlongString();
 preproc.init(feats_train);
-feats_train.add_preproc(preproc);
-feats_train.apply_preproc();
+feats_train.add_preprocessor(preproc);
+feats_train.apply_preprocessor();
 
 charfeat=StringCharFeatures(DNA);
 charfeat.set_features(fm_test_dna);
 feats_test=StringUlongFeatures(charfeat.get_alphabet());
 feats_test.obtain_from_char(charfeat, order-1, order, gap, reverse);
-feats_test.add_preproc(preproc);
-feats_test.apply_preproc();
+feats_test.add_preprocessor(preproc);
+feats_test.apply_preprocessor();
 
 use_sign=false;
 
