@@ -8,12 +8,12 @@ fm_test_byte=uint8(load_matrix('../data/fm_test_byte.dat'));
 disp('LinearByte')
 
 feats_train=ByteFeatures(RAWBYTE);
-feats_train.copy_feature_matrix(fm_train_byte);
+feats_train.set_feature_matrix(fm_train_byte);
 
 feats_test=ByteFeatures(RAWBYTE);
-feats_test.copy_feature_matrix(fm_test_byte);
+feats_test.set_feature_matrix(fm_test_byte);
 
-kernel=LinearByteKernel(feats_train, feats_train);
+kernel=LinearKernel(feats_train, feats_train);
 
 km_train=kernel.get_kernel_matrix();
 kernel.init(feats_train, feats_test);
