@@ -5,8 +5,8 @@ label_train=load_matrix('../data/label_train_twoclass.dat');
 fm_train=load_matrix('../data/fm_train_real.dat');
 fm_test=load_matrix('../data/fm_test_real.dat');
 
-% libsvm based support vector regression
-if exist('SVRLight')
+% svmlight based support vector regression
+try
 	disp('SVRLight')
 
 	feats_train=RealFeatures(fm_train);
@@ -27,6 +27,6 @@ if exist('SVRLight')
 
 	kernel.init(feats_train, feats_test);
 	svr.apply().get_labels();
-else
+catch
 	disp('No support for SVRLight available.')
 end
