@@ -20,8 +20,9 @@ def classifier_knn_modular(fm_train_real=traindat,fm_test_real=testdat,label_tra
 
 	knn=KNN(k, distance, labels)
 	knn_train = knn.train()
-	output=knn.classify(feats_test).get_labels()
-	return knn,knn_train,output
+	output=knn.apply(feats_test).get_labels()
+	multiple_k=knn.classify_for_multiple_k()
+	return knn,knn_train,output,multiple_k
 
 if __name__=='__main__':
 	print 'KNN'
