@@ -12,7 +12,7 @@ def classifier_liblinear_modular(fm_train_real, fm_test_real,
 
 	from shogun.Features import RealFeatures, SparseRealFeatures, Labels
 	from shogun.Classifier import LibLinear, L2R_L2LOSS_SVC_DUAL
-	from shogun.Library import Math_init_random
+	from shogun.Mathematics import Math_init_random
 	Math_init_random(17)
 
 	feats_train=RealFeatures(fm_train_real)
@@ -26,8 +26,8 @@ def classifier_liblinear_modular(fm_train_real, fm_test_real,
 	svm.train()
 
 	svm.set_features(feats_test)
-	svm.classify().get_labels()
-	predictions = svm.classify()
+	svm.apply().get_labels()
+	predictions = svm.apply()
 	return predictions, svm, predictions.get_labels()
 
 
