@@ -24,6 +24,6 @@ svm=LibSVM(C, kernel, labels);
 svm.train();
 
 kernel.init(feats_train, feats_test);
-out=svm.classify().get_labels();
+out=svm.apply().get_labels();
 testerr=mean(sign(out)!=testlab)
 print testerr
