@@ -28,8 +28,8 @@ def classifier_svmocas_modular (fm_train_real=traindat,fm_test_real=testdat,labe
 	svm.train()
 
 	svm.set_features(feats_test)
-	svm.classify().get_labels()
-	predictions = svm.classify()
+	svm.apply().get_labels()
+	predictions = svm.apply()
 	return predictions, svm, predictions.get_labels()
 
 if __name__=='__main__':
