@@ -27,8 +27,8 @@ def classifier_svmsgd_modular (fm_train_real=traindat,fm_test_real=testdat,label
 	svm.train()
 
 	svm.set_features(feats_test)
-	svm.classify().get_labels()
-	predictions = svm.classify()
+	svm.apply().get_labels()
+	predictions = svm.apply()
 	return predictions, svm, predictions.get_labels()
 
 
