@@ -1,6 +1,12 @@
-def canberra_metric ():
-	print 'CanberaMetric'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
 
+traindat = lm.load_numbers('../data/fm_train_real.dat')
+testdat = lm.load_numbers('../data/fm_test_real.dat')
+
+parameter_list = [[traindat,testdat],[traindat,testdat]]
+
+def distance_canberra_modular (fm_train_real=traindat,fm_test_real=testdat):
 	from shogun.Features import RealFeatures
 	from shogun.Distance import CanberraMetric
 
@@ -12,11 +18,8 @@ def canberra_metric ():
 	dm_train=distance.get_distance_matrix()
 	distance.init(feats_train, feats_test)
 	dm_test=distance.get_distance_matrix()
-
+	return distance,dm_train,dm_test
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_real=lm.load_numbers('../data/fm_train_real.dat')
-	fm_test_real=lm.load_numbers('../data/fm_test_real.dat')
-	canberra_metric()
+	print 'CanberaMetric'
+	distance_canberra_modular(*parameter_list[0])
