@@ -1,5 +1,12 @@
-def jensen_metric ():
-	print 'JensenMetric'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+
+traindat = lm.load_numbers('../data/fm_train_real.dat')
+testdat = lm.load_numbers('../data/fm_test_real.dat')
+
+parameter_list = [[traindat,testdat],[traindat,testdat]]
+
+def distance_jensen_modular (fm_train_real=traindat,fm_test_real=testdat):
 
 	from shogun.Features import RealFeatures
 	from shogun.Distance import JensenMetric
@@ -12,11 +19,8 @@ def jensen_metric ():
 	dm_train=distance.get_distance_matrix()
 	distance.init(feats_train, feats_test)
 	dm_test=distance.get_distance_matrix()
-
+	return distance,dm_train,dm_test
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_real=lm.load_numbers('../data/fm_train_real.dat')
-	fm_test_real=lm.load_numbers('../data/fm_test_real.dat')
-	jensen_metric()
+	print 'JensenMetric'
+	distance_jensen_modular(*parameter_list[0])
