@@ -10,7 +10,7 @@ parameter_list = [[traindna,testdna,testdat,3,0,False],[traindna,testdna,testdat
 def distance_manhattenword_modular (fm_train_dna=traindna ,fm_test_dna=testdna,fm_test_real=testdat,order=3,gap=0,reverse=False):
 
 	from shogun.Features import StringCharFeatures, StringWordFeatures, DNA
-	from shogun.PreProc import SortWordString
+	from shogun.Preprocessor import SortWordString
 	from shogun.Distance import ManhattanWordDistance
 
 	charfeat=StringCharFeatures(DNA)
@@ -19,15 +19,15 @@ def distance_manhattenword_modular (fm_train_dna=traindna ,fm_test_dna=testdna,f
 	feats_train.obtain_from_char(charfeat, order-1, order, gap, reverse)
 	preproc=SortWordString()
 	preproc.init(feats_train)
-	feats_train.add_preproc(preproc)
-	feats_train.apply_preproc()
+	feats_train.add_preprocessor(preproc)
+	feats_train.apply_preprocessor()
 
 	charfeat=StringCharFeatures(DNA)
 	charfeat.set_features(fm_test_dna)
 	feats_test=StringWordFeatures(charfeat.get_alphabet())
 	feats_test.obtain_from_char(charfeat, order-1, order, gap, reverse)
-	feats_test.add_preproc(preproc)
-	feats_test.apply_preproc()
+	feats_test.add_preprocessor(preproc)
+	feats_test.apply_preprocessor()
 
 	distance=ManhattanWordDistance(feats_train, feats_train)
 
