@@ -9,7 +9,7 @@ def features_io_modular(fm_train_real, label_train_twoclass):
 	import numpy
 	from shogun.Features import SparseRealFeatures, RealFeatures, Labels
 	from shogun.Kernel import GaussianKernel
-	from shogun.Library import AsciiFile, BinaryFile, HDF5File
+	from shogun.IO import AsciiFile, BinaryFile, HDF5File
 
 	feats=SparseRealFeatures(fm_train_real)
 	feats2=SparseRealFeatures()
