@@ -2,8 +2,8 @@ parameter_list = [['features_string_char_compressed_modular.py']]
 
 def features_string_char_compressed_modular(fname):
 	from shogun.Features import StringCharFeatures, StringFileCharFeatures, RAWBYTE
-	from shogun.Library import UNCOMPRESSED,LZO,GZIP,BZIP2,LZMA, MSG_DEBUG
-	from shogun.PreProc import DecompressCharString
+	from shogun.Library import UNCOMPRESSED,SNAPPY,LZO,GZIP,BZIP2,LZMA, MSG_DEBUG
+	from shogun.Preprocessor import DecompressCharString
 
 	f=StringFileCharFeatures(fname, RAWBYTE)
 
@@ -18,6 +18,13 @@ def features_string_char_compressed_modular(fname):
 
 	# load compressed data and uncompress on load
 
+	#snappy - not stable yet?!
+	#f.save_compressed("foo_snappy.str", SNAPPY, 9)
+	#f2=StringCharFeatures(RAWBYTE);
+	#f2.load_compressed("foo_snappy.str", True)
+	#print "snappy strings", f2.get_features()
+	#print
+
 	#lzo
 	f.save_compressed("foo_lzo.str", LZO, 9)
 	f2=StringCharFeatures(RAWBYTE);
@@ -49,8 +56,8 @@ def features_string_char_compressed_modular(fname):
 	# load compressed data and uncompress via preprocessor
 	f2=StringCharFeatures(RAWBYTE);
 	f2.load_compressed("foo_lzo.str", False)
-	f2.add_preproc(DecompressCharString(LZO))
-	f2.apply_preproc()
+	f2.add_preprocessor(DecompressCharString(LZO))
+	f2.apply_preprocessor()
 	#print "lzo strings", f2.get_features()
 	#print
 
@@ -58,14 +65,14 @@ def features_string_char_compressed_modular(fname):
 	f2=StringCharFeatures(RAWBYTE);
 	f2.load_compressed("foo_lzo.str", False)
 	#f2.io.set_loglevel(MSG_DEBUG)
-	f2.add_preproc(DecompressCharString(LZO))
+	f2.add_preprocessor(DecompressCharString(LZO))
 	f2.enable_on_the_fly_preprocessing()
 	#print "lzo strings", f2.get_features()
 	#print
 
 	#clean up
 	import os
-	for f in ['foo_uncompressed.str', 'foo_lzo.str', 'foo_gzip.str',
+	for f in ['foo_uncompressed.str', 'foo_snappy.str', 'foo_lzo.str', 'foo_gzip.str',
 	'foo_bzip2.str', 'foo_lzma.str', 'foo_lzo.str', 'foo_lzo.str']:
 		if os.path.exists(f):
 			os.unlink(f)
