@@ -19,7 +19,7 @@ svr = LibSVR(C, epsilon, gk, lab)
 svr.train()
 
 plot(X, Y, '.', label='train data')
-plot(X[0], svr.classify().get_labels(), hold=True, label='train output')
+plot(X[0], svr.apply().get_labels(), hold=True, label='train output')
 
 XE, YE=util.compute_output_plot_isolines_sine(svr, gk, feat)
 plot(XE[0], YE, hold=True, label='test output')
