@@ -9,7 +9,7 @@ def kernel_comm_ulong_string_modular (fm_train_dna=traindat,fm_test_dna=testdat,
 
 	from shogun.Kernel import CommUlongStringKernel
 	from shogun.Features import StringUlongFeatures, StringCharFeatures, DNA
-	from shogun.PreProc import SortUlongString
+	from shogun.Preprocessor import SortUlongString
 
 	charfeat=StringCharFeatures(DNA)
 	charfeat.set_features(fm_train_dna)
@@ -17,16 +17,16 @@ def kernel_comm_ulong_string_modular (fm_train_dna=traindat,fm_test_dna=testdat,
 	feats_train.obtain_from_char(charfeat, order-1, order, gap, reverse)
 	preproc=SortUlongString()
 	preproc.init(feats_train)
-	feats_train.add_preproc(preproc)
-	feats_train.apply_preproc()
+	feats_train.add_preprocessor(preproc)
+	feats_train.apply_preprocessor()
 
 
 	charfeat=StringCharFeatures(DNA)
 	charfeat.set_features(fm_test_dna)
 	feats_test=StringUlongFeatures(charfeat.get_alphabet())
 	feats_test.obtain_from_char(charfeat, order-1, order, gap, reverse)
-	feats_test.add_preproc(preproc)
-	feats_test.apply_preproc()
+	feats_test.add_preprocessor(preproc)
+	feats_test.apply_preprocessor()
 
 	use_sign=False
 
