@@ -1,11 +1,15 @@
-def custom ():
-	print 'Custom'
-	from numpy.random import rand
+from numpy.random import seed
+seed(42)
+
+parameter_list=[[7],[8]]
+
+def kernel_custom_modular (dim=7):
+	from numpy.random import rand, seed
 	from numpy import array, float32
 	from shogun.Features import RealFeatures
 	from shogun.Kernel import CustomKernel
 
-	dim=7
+	seed(17)
 	data=rand(dim, dim)
 	feats=RealFeatures(data)
 	symdata=data+data.T
@@ -35,9 +39,9 @@ def custom ():
 
 	kernel.set_full_kernel_matrix_from_full(data)
 	km_fullfull=kernel.get_kernel_matrix()
+	return km_fullfull,kernel
 
 if __name__=='__main__':
-	from numpy.random import seed
-	seed(42)
-	custom()
+	print 'Custom'
+	kernel_custom_modular(*parameter_list[0])
 
