@@ -1,17 +1,19 @@
-def diag ():
-	print 'Diag'
+parameter_list =[[23],[24]]
+def kernel_diag_modular (diag=23):
 	from shogun.Features import DummyFeatures
 	from shogun.Kernel import DiagKernel
 
 	feats_train=DummyFeatures(10)
 	feats_test=DummyFeatures(17)
-	diag=23.
 
 	kernel=DiagKernel(feats_train, feats_train, diag)
 
 	km_train=kernel.get_kernel_matrix()
 	kernel.init(feats_train, feats_test)
 	km_test=kernel.get_kernel_matrix()
+	return km_train,km_test,kernel
 
 if __name__=='__main__':
-	diag()
+	print 'Diag'
+	kernel_diag_modular(*parameter_list[0])
+	
