@@ -1,5 +1,12 @@
-def local_alignment_string():
-	print 'LocalAlignmentString'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+
+traindat = lm.load_dna('../data/fm_train_dna.dat')
+testdat = lm.load_dna('../data/fm_test_dna.dat')
+parameter_list=[[traindat,testdat],[traindat,testdat]]
+
+def kernel_local_alignment_string_modular(fm_train_dna=traindat,fm_test_dna=testdat):
+
 	from shogun.Features import StringCharFeatures, DNA
 	from shogun.Kernel import LocalAlignmentStringKernel
 
@@ -8,14 +15,11 @@ def local_alignment_string():
 
 	kernel=LocalAlignmentStringKernel(feats_train, feats_train)
 	km_train=kernel.get_kernel_matrix()
-
+	
 	kernel.init(feats_train, feats_test)
 	km_test=kernel.get_kernel_matrix()
-
+	return km_train,km_test,kernel
 
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_dna=lm.load_dna('../data/fm_train_dna.dat')
-	fm_test_dna=lm.load_dna('../data/fm_test_dna.dat')
-	local_alignment_string()
+	print 'LocalAlignmentString'
+	kernel_local_alignment_string_modular(*parameter_list[0])
