@@ -1,15 +1,16 @@
-def match_word_string ():
-	print 'MatchWordString'
+from tools.load import LoadMatrix
+lm=LoadMatrix()
+traindat = lm.load_dna('../data/fm_train_dna.dat')
+testdat = lm.load_dna('../data/fm_test_dna.dat')
+
+parameter_list = [[traindat,testdat, 3,1.4,10,3,0,False],[
+traindat,testdat, 3,1.4,10,3,0,False]]
+
+def kernel_match_word_string_modular (fm_train_dna=traindat,fm_test_dna=testdat, 
+degree=3,scale=1.4,size_cache=10,order=3,gap=0,reverse=False):
 	from shogun.Kernel import MatchWordStringKernel, AvgDiagKernelNormalizer
 	from shogun.Features import StringWordFeatures, StringCharFeatures, DNA
 
-	degree=3
-	scale=1.4
-	size_cache=10
-	order=3
-	gap=0
-	reverse=False
-
 	charfeat=StringCharFeatures(fm_train_dna, DNA)
 	feats_train=StringWordFeatures(DNA)
 	feats_train.obtain_from_char(charfeat, order-1, order, gap, reverse)
@@ -25,10 +26,9 @@ def match_word_string ():
 	km_train=kernel.get_kernel_matrix()
 	kernel.init(feats_train, feats_test)
 	km_test=kernel.get_kernel_matrix()
-
+	return km_train,km_test,kernel
+	
 if __name__=='__main__':
-	from tools.load import LoadMatrix
-	lm=LoadMatrix()
-	fm_train_dna=lm.load_dna('../data/fm_train_dna.dat')
-	fm_test_dna=lm.load_dna('../data/fm_test_dna.dat')
-	match_word_string()
+	print 'MatchWordString'
+	kernel_match_word_string_modular(*parameter_list[0])
+	
