@@ -10,7 +10,7 @@ traindat = lm.load_numbers('../data/fm_train_real.dat')
 testdat = lm.load_numbers('../data/fm_test_real.dat')
 label_traindat = lm.load_labels('../data/label_train_twoclass.dat')
 
-parameter_list = [[traindat,testdat,label_traindat,1.2,1,1e-5,1e-2,3],[traindat,testdat,label_traindat,2.3,0.5,1e-5,1e-6,1]]
+parameter_list = [[traindat,testdat,label_traindat,1.2,1,1e-5,1e-2,1],[traindat,testdat,label_traindat,2.3,0.5,1e-5,1e-6,1]]
 
 def regression_svrlight_modular(fm_train=traindat,fm_test=testdat,label_train=label_traindat, \
 				    width=1.2,C=1,epsilon=1e-5,tube_epsilon=1e-2,num_threads=3):
@@ -37,7 +37,7 @@ def regression_svrlight_modular(fm_train=traindat,fm_test=testdat,label_train=la
 	svr.train()
 
 	kernel.init(feats_train, feats_test)
-	out = svr.classify().get_labels()
+	out = svr.apply().get_labels()
 	
 	return out, kernel 
 
