@@ -35,10 +35,19 @@ def mapname(name):
 		return renametable[name]
 	return name
 
+# scipy compatibility class
+class mat_struct(object):
+    pass
+
 def mapped_load_global(self):
 	module = mapname(self.readline()[:-1])
 	name = mapname(self.readline()[:-1])
-	klass = self.find_class(module, name)
+
+	if name=='mat_struct':
+		klass=mat_struct
+	else:
+		klass = self.find_class(module, name)
+
 	self.append(klass)
 
 def loads(str):
@@ -154,17 +163,17 @@ def structure_dynprog_modular(fname):
 
 	dyn.set_plif_matrices(pm);
 
-	dyn.compute_nbest_paths(features.shape[2], use_orf, 1,True,False)
+	#dyn.compute_nbest_paths(features.shape[2], use_orf, 1,True,False)
 
-	# fetch results
-	states = dyn.get_states()
-	#print states
-	scores = dyn.get_scores()
-	#print scores
-	positions = dyn.get_positions()
-	#print positions
+	## fetch results
+	#states = dyn.get_states()
+	##print states
+	#scores = dyn.get_scores()
+	##print scores
+	#positions = dyn.get_positions()
+	##print positions
 
-	return states, scores, positions
+	#return states, scores, positions
 
 if __name__ == '__main__':
 	print "Structure"
