@@ -3,7 +3,7 @@ parameter_list=[[10,7,0,0]]
 def tests_check_commwordkernel_memleak_modular(num, order, gap, reverse):
 	import gc
 	from shogun.Features import Alphabet,StringCharFeatures,StringWordFeatures,DNA
-	from shogun.PreProc import SortWordString, MSG_DEBUG
+	from shogun.Preprocessor import SortWordString, MSG_DEBUG
 	from shogun.Kernel import CommWordStringKernel, IdentityKernelNormalizer
 	from numpy import mat
 
@@ -66,8 +66,8 @@ def tests_check_commwordkernel_memleak_modular(num, order, gap, reverse):
 		pre = SortWordString()
 		#pre.io.set_loglevel(MSG_DEBUG)
 		pre.init(trainudat)
-		trainudat.add_preproc(pre)
-		trainudat.apply_preproc()
+		trainudat.add_preprocessor(pre)
+		trainudat.apply_preprocessor()
 		spec = CommWordStringKernel(10, False)
 		spec.set_normalizer(IdentityKernelNormalizer())
 		spec.init(trainudat, trainudat)
