@@ -19,5 +19,5 @@ dump <- lda$train(lda)
 dump <- lda$get_bias(lda)
 dump <- lda$get_w(lda)
 dump <- lda$set_features(lda, feats_test)
-lab <- lda$classify(lda)
+lab <- lda$apply(lda)
 out <- lab$get_labels(lab)
