@@ -57,5 +57,5 @@ dump <- svm$set_mkl_epsilon(svm,mkl_eps)
 dump <- svm$train(svm)
 
 dump <- kernel$init(kernel, feats_train, feats_test)
-lab <- svm$classify(svm)
+lab <- svm$apply(svm)
 out <- lab$get_labels(lab)
