@@ -2,13 +2,18 @@
 
 rm -f error.log
 
+if [ -z "${RUBY}" ]
+then
+	RUBY=ruby
+fi
+
 if test -z "$1"
 then
 	for e in $(ls -1 *.rb | grep -v ruby | grep -v shogun_helpers)
 	do
 		echo -n $e
 
-		if ruby $e >/dev/null 2>&1
+		if $RUBY $e >/dev/null 2>&1
 		then
 			echo " OK"
 		else
@@ -16,14 +21,14 @@ then
 			echo "================================================================================" >>error.log
 			echo " error in $e ">>error.log
 			echo "================================================================================" >>error.log
-			ruby "$e" >>error.log 2>&1
+			$RUBY "$e" >>error.log 2>&1
 			echo "================================================================================" >>error.log
 			echo >>error.log
 			echo >>error.log
 		fi
 	done
 else
-	ruby $1
+	$RUBY $1
 fi
 
 if test -f error.log 
