@@ -1,5 +1,16 @@
 import os,re,sys
 
+f=None
+BASEDIR=None
+try:
+	f=file('../.config')
+	BASEDIR='../'
+except:
+	f=file('../../.config')
+	BASEDIR='../../'
+
+have_doxygen=f.read().find('-DHAVE_DOXYGEN') is not -1
+
 try:
 	prefix=sys.argv[1]
 	suffix=sys.argv[2]
@@ -7,29 +18,18 @@ except IndexError:
 	prefix='_'
 	suffix='so'
 
-if len(sys.argv)>3 and sys.argv[3]=='external':
+if len(sys.argv)>4 and sys.argv[4]=='external':
 	incexpr=re.compile('^\s*[%#]include ("(\S+)")',re.MULTILINE)
 else:
 	incexpr=re.compile('^\s*[%#]include ("(\S+)"|<shogun/(\S+)>)',re.MULTILINE)
 
 deps=dict();
-deps['carrays.i']=[]
-deps['cpointer.i']=[]
+deps['enumtypeunsafe.swg']=[]
 deps['exception.i']=[]
 deps['stdint.i']=[]
-deps['std_string.i']=[]
-deps['Library_doxygen.i']=[]
-deps['Features_doxygen.i']=[]
-deps['Classifier_doxygen.i']=[]
-deps['Structure_doxygen.i']=[]
-deps['Regression_doxygen.i']=[]
-deps['Kernel_doxygen.i']=[]
-deps['PreProc_doxygen.i']=[]
-deps['Distribution_doxygen.i']=[]
-deps['Classifier_doxygen.i']=[]
-deps['Clustering_doxygen.i']=[]
-deps['Distance_doxygen.i']=[]
-deps['Evaluation_doxygen.i']=[]
+deps['modshogun_doxygen.i']=[]
+
+modular_deps=['modshogun_doxygen.i']
 
 initial_deps=deps.copy()
 
@@ -59,9 +59,9 @@ for f in files:
 		if i[1]:
 			i=i[1]
 			if i.endswith('.h'):
-				i='../shogun/' + i
+				i=BASEDIR + 'shogun/' + i
 		else:
-			i='../shogun/' + i[2]
+			i=BASEDIR + 'shogun/' + i[2]
 
 		dd.append(i)
 
@@ -69,6 +69,7 @@ for f in files:
 	#print f,deps[f]
 	#import pdb
 	#pdb.set_trace()
+
 #'./../modular'
 #generate linker dependencies
 for f in deps.iterkeys():
@@ -77,6 +78,9 @@ for f in deps.iterkeys():
 			str1=os.path.join(os.path.dirname(f), prefix + os.path.basename(f)[:-2]) + suffix + ': ' + f[:-2]+'_wrap.cxx.o' + ' sg_print_functions.cpp.o'
 			str2=os.path.join(os.path.dirname(f), os.path.basename(f)[:-2]) + '_wrap.cxx: ' + f
 
+			if have_doxygen:
+				str2+=' ' + ' '.join([os.path.join(os.path.dirname(f), m) for m in modular_deps])
+
 			fdep=list();
 			#if not f.startswith('./../modular/'):
 			#	get_deps('./../modular/' + f)
