@@ -1576,7 +1576,7 @@ TParameter::TParameter(const TSGDataType* datatype, void* parameter,
 	m_description = strdup(description);
 }
 
-TParameter::~TParameter(void)
+TParameter::~TParameter()
 {
 	SG_FREE(m_description);
 	SG_FREE(m_name);
@@ -1613,7 +1613,7 @@ TParameter::print(const char* prefix)
 }
 
 void
-TParameter::delete_cont(void)
+TParameter::delete_cont()
 {
 	/* In the case, ctype is a struct (not array of a basic type)
 	 * data does not start at m_parameter, since the latter may have
@@ -1622,10 +1622,10 @@ TParameter::delete_cont(void)
 	switch(m_datatype.m_ctype)
 	{
 	case CT_SGVECTOR:
-		data_start=&(((SGVector<void>*)m_parameter)->vector);
+		data_start=&(((SGVector<char>*)m_parameter)->vector);
 		break;
 	case CT_SGMATRIX:
-		data_start=&(((SGMatrix<void>*)m_parameter)->matrix);
+		data_start=&(((SGMatrix<char>*)m_parameter)->matrix);
 		break;
 	default:
 		break;
@@ -1783,10 +1783,10 @@ TParameter::new_cont(index_t new_len_y, index_t new_len_x)
 	switch(m_datatype.m_ctype)
 	{
 	case CT_SGVECTOR:
-		data_start=&(((SGVector<void>*)m_parameter)->vector);
+		data_start=&(((SGVector<char>*)m_parameter)->vector);
 		break;
 	case CT_SGMATRIX:
-		data_start=&(((SGMatrix<void>*)m_parameter)->matrix);
+		data_start=&(((SGMatrix<char>*)m_parameter)->matrix);
 		break;
 	default:
 		break;
@@ -2247,10 +2247,10 @@ TParameter::save(CSerializableFile* file, const char* prefix)
 				switch(m_datatype.m_ctype)
 				{
 				case CT_SGVECTOR:
-					data_start=&(((SGVector<void>*)m_parameter)->vector);
+					data_start=&(((SGVector<char>*)m_parameter)->vector);
 					break;
 				case CT_SGMATRIX:
-					data_start=&(((SGMatrix<void>*)m_parameter)->matrix);
+					data_start=&(((SGMatrix<char>*)m_parameter)->matrix);
 					break;
 				default:
 					break;
@@ -2338,10 +2338,10 @@ TParameter::load(CSerializableFile* file, const char* prefix)
 					switch(m_datatype.m_ctype)
 					{
 					case CT_SGVECTOR:
-						data_start=&(((SGVector<void>*)m_parameter)->vector);
+						data_start=&(((SGVector<char>*)m_parameter)->vector);
 						break;
 					case CT_SGMATRIX:
-						data_start=&(((SGMatrix<void>*)m_parameter)->matrix);
+						data_start=&(((SGMatrix<char>*)m_parameter)->matrix);
 						break;
 					default:
 						break;
@@ -2385,12 +2385,12 @@ TParameter::load(CSerializableFile* file, const char* prefix)
 	return true;
 }
 
-Parameter::Parameter(void)
+Parameter::Parameter()
 {
 	SG_REF(sg_io);
 }
 
-Parameter::~Parameter(void)
+Parameter::~Parameter()
 {
 	for (int32_t i=0; i<get_num_parameters(); i++)
 		delete m_params.get_element(i);
