@@ -22,16 +22,12 @@
 #include <shogun/kernel/KernelNormalizer.h>
 
 #include <vector>
-#include <set>
-#include <string>
 
 namespace shogun
 {
 	class CFile;
 	class CFeatures;
 	class CKernelNormalizer;
-	enum EFeatureType;
-	enum EFeatureClass;
 
 #ifdef USE_SHORTREAL_KERNELCACHE
 	/** kernel cache element */
@@ -244,18 +240,15 @@ class CKernel : public CSGObject
 		 *
 		 * @return the jth column of the kernel matrix
 		 */
-		virtual std::vector<float64_t> get_kernel_col(int32_t j)
+		virtual SGVector<float64_t> get_kernel_col(int32_t j)
         {
 
-            std::vector<float64_t> col = std::vector<float64_t>(num_rhs);
+            SGVector<float64_t> col = SGVector<float64_t>(num_rhs);
 
             for (int32_t i=0; i!=num_rhs; i++)
-            {
                 col[i] = kernel(i,j);
-            }
 
         	return col;
-
         }
 
 
@@ -264,18 +257,14 @@ class CKernel : public CSGObject
 		 *
 		 * @return the ith row of the kernel matrix
 		 */
-		virtual std::vector<float64_t> get_kernel_row(int32_t i)
+		virtual SGVector<float64_t> get_kernel_row(int32_t i)
         {
-
-            std::vector<float64_t> row = std::vector<float64_t>(num_lhs);
+            SGVector<float64_t> row = SGVector<float64_t>(num_lhs);
 
             for (int32_t j=0; j!=num_lhs; j++)
-            {
                 row[j] = kernel(i,j);
-            }
 
         	return row;
-
         }
 
 		/** get kernel matrix real
@@ -376,7 +365,7 @@ class CKernel : public CSGObject
 
 			SG_DONE();
 
-			return SGMatrix<T>(result,m,n);
+			return SGMatrix<T>(result,m,n,true);
 		}
 
 
@@ -647,11 +636,9 @@ class CKernel : public CSGObject
 
 		/** set subkernel weights
 		 *
-		 * @param weights subkernel weights
-		 * @param num_weights number of weights
+		 * @param weights new subkernel weights
 		 */
-		virtual void set_subkernel_weights(
-			float64_t* weights, int32_t num_weights);
+		virtual void set_subkernel_weights(SGVector<float64_t> weights);
 
 	protected:
 		/** set property
