@@ -49,7 +49,7 @@ class CWeightedDegreePositionStringKernel: public CStringKernel<char>
 {
 	public:
 		/** default constructor  */
-		CWeightedDegreePositionStringKernel(void);
+		CWeightedDegreePositionStringKernel();
 
 		/** constructor
 		 *
@@ -271,9 +271,11 @@ class CWeightedDegreePositionStringKernel: public CStringKernel<char>
 		 * @param weights2 weights
 		 * @param num_weights2 number of weights
 		 */
-		inline void set_subkernel_weights(
-			float64_t* weights2, int32_t num_weights2)
+		virtual void set_subkernel_weights(SGVector<float64_t> w)
 		{
+			float64_t* weights2=w.vector;
+			int32_t num_weights2=w.vlen;
+
 			int32_t num_weights = get_num_subkernels() ;
 			if (num_weights!=num_weights2)
 				SG_ERROR( "number of weights do not match\n") ;
@@ -691,7 +693,7 @@ class CWeightedDegreePositionStringKernel: public CStringKernel<char>
 		 *  @exception ShogunException Will be thrown if an error
 		 *                             occurres.
 		 */
-		virtual void load_serializable_post(void) throw (ShogunException);
+		virtual void load_serializable_post() throw (ShogunException);
 
 	private:
 		/** Do basic initialisations like default settings
