@@ -21,6 +21,7 @@
 #include <shogun/mathematics/lapack.h>
 #include <shogun/base/SGObject.h>
 #include <shogun/base/Parallel.h>
+#include <shogun/lib/DataType.h>
 
 #include <math.h>
 #include <stdio.h>
@@ -389,7 +390,11 @@ class CMath : public CSGObject
 
 		static inline floatmax_t lgammal(floatmax_t x)
 		{
+#ifdef HAVE_LGAMMAL
 			return ::lgammal((long double) x);
+#else
+			return ::lgamma((double) x);
+#endif // HAVE_LGAMMAL
 		}
 
 		static inline float64_t log10(float64_t v)
