@@ -24,11 +24,10 @@ function y = preproc(filename)
 		return;
 	end
 
-	kmatrix=sg('get_kernel_matrix');
+	kmatrix=sg('get_kernel_matrix', 'TRAIN');
 	km_train=max(max(abs(kernel_matrix_train-kmatrix)));
 
-	sg('init_kernel', 'TEST');
-	kmatrix=sg('get_kernel_matrix');
+	kmatrix=sg('get_kernel_matrix', 'TEST');
 	km_test=max(max(abs(kernel_matrix_test-kmatrix)));
 
 	data={'kernel', km_train, km_test};
