@@ -3,10 +3,16 @@
 DATAPATH='../data'
 
 function test_all () {
-	dir=${1}
-	echo "*** Testing in ${dir}"
+	datapath=${1}
+
+	if echo "$datapath" | grep -q '\.\./data/tests'
+	then
+		continue
+	fi
+
+	echo "*** Testing in ${datapath}"
 	sleep 1
-	for file in ${dir}; do
+	for file in ${datapath}; do
 		dump=`echo ${file} | grep WDSVMOcas`
 		if [ $? -eq 0 ]; then
 			echo WDSVMOcas totally unsupported: ERROR
